;*******************************************************************************
;*
;*	Titel:	Bibliothek mit Entprellprogrammen (SR_DEBOUNCE.asm)
;*	Datum:	10/05/07	Version:	0.1	
;*	Autor:	WEIGU
;*
;*	Informationen zur Beschaltung:
;*	Prozessor:	ATMEGA32	Quarzfrequenz:	 extern 16MHz
;*	Eingaenge:	1 Schalter oder Taster an beliebigen Port oder Pin
;*			geschaltet gegen Masse mit Pull-Up gegen VCC
;*			
;*	Informationen zur Funktionsweise:
;*
;*	Die Unterprogramme dienen der softwaremaessigen Entprellung von
;*	Schaltern (switch) oder Tastern (bushbutton). 
;*	Der Port und Pin des Schalters bzw. Tasters wird im Hauptprogramm mit
;*	dem Namen SWPinC bzw. PBPinC und SwitchC bzw. PButtC uebergeben:
;*	(Bsp.: .EQU PBPinC = PIND	.EQU PButtC = 5; C fuer Closer,
;*      ( O fuer Opener)
;*	Im Hauptprogramm muss auch die Zeitschleifenbibliothek SR_Time_16M.asm
;*	mit eingebunden werden.
;*	
;*	Es gibt zwei Unterprogramme fuer Taster und zwei Unterprogramme 
;*	fuer Schalter:
;*
;*	DEBSWC: 
;*	Entprellprogramm fuer einen schliessenden Schalter (closer).
;*	Offen (unbetaetigt) liegt Eins am Pin, geschlossen (betaetigt) Null.
;*	
;*	DEBSWO: 
;*	Entprellprogramm fuer einen oeffnenden Schalter (opener).
;*	Geschlossen (unbetaetigt) liegt Null am Pin, Offen (betaetigt) Eins.
;*
;*	DEBPBC: 
;*	Entprellprogramm fuer einen schliessenden Taster (closer).
;*	Es wird auch das Loslassen des Tasters abgewartet!
;*	Offen (unbetaetigt) liegt Eins am Pin, geschlossen (betaetigt) Null.
;*	
;*	DEBSWO: 
;*	Entprellprogramm fuer einen oeffnenden Taster (opener).
;*	Es wird auch das Loslassen des Tasters abgewartet!
;*	Geschlossen (unbetaetigt) liegt Null am Pin, Offen (betaetigt) Eins.
;*
;*
;*******************************************************************************

;-------------------------------------------------------------------------------
;	Entprellprogramm fuer einen schliessenden Schalter (closer).
;	Offen (unbetaetigt) liegt Eins am Pin, geschlossen (betaetigt)
;-------------------------------------------------------------------------------

DEBSWC:	sbis    SWPinC,SwitchC  ;Sicherstellen eines definierten Ausgangs-
        rjmp	DEBSWC          ;zustandes
DEBSWC1: sbic   SWPinC,SwitchC  ;Warten auf erste Schalterbetaetigung
        rjmp	DEBSWC1
	rcall	W10ms		;Totzeit
        sbic    SWPinC,SwitchC  ;Bestätigung des Schaltzustandes
        rjmp	DEBSWC1
	ret

;-------------------------------------------------------------------------------
;	Entprellprogramm fuer einen oeffnenden Schalter (opener).
;	Geschlossen (unbetaetigt) liegt Null am Pin, Offen (betaetigt) Eins.
;-------------------------------------------------------------------------------

DEBSWO:	sbic    SWPinO,SwitchO  ;Sicherstellen eines definierten Ausgangs-
        rjmp	DEBSWO          ;zustandes
DEBSWO1: sbis   SWPinO,SwitchO  ;Warten auf erste Schalterbetaetigung
        rjmp	DEBSWO1
	rcall	W10ms		;Totzeit
        sbis    SWPinO,SwitchO  ;Bestätigung des Schaltzustandes
        rjmp	DEBSWO1
	ret

;-------------------------------------------------------------------------------
;	Entprellprogramm fuer einen schliessenden Taster (closer).
;	Es wird auch das Loslassen des Tasters abgewartet!
;	Offen (unbetaetigt) liegt Eins am Pin, geschlossen (betaetigt) Null.
;-------------------------------------------------------------------------------

DEBPBC:	sbis    PBPinC,PButtC   ;Sicherstellen eines definierten Ausgangs-
        rjmp	DEBPBC          ;zustandes
DEBPBC1: sbic   PBPinC,PButtC   ;Warten auf erste Tasterbetaetigung
        rjmp	DEBPBC1
	rcall	W10ms		;Totzeit
        sbic    PBPinC,PButtC   ;Bestätigung des Schaltzustandes
        rjmp	DEBPBC1

DEBPBC2: sbis   PBPinC,PButtC   ;Warten auf Loslassen des Tasters
        rjmp	DEBPBC2
	rcall	W10ms		;Totzeit
        sbis    PBPinC,PButtC   ;Bestätigung des Loslassens
        rjmp	DEBPBC2
	ret

;-------------------------------------------------------------------------------
;	Entprellprogramm fuer einen oeffnenden Taster (opener).
;	Es wird auch das Loslassen des Tasters abgewartet!
;	Geschlossen (unbetaetigt) liegt Null am Pin, Offen (betaetigt) Eins.
;-------------------------------------------------------------------------------

DEBPBO:	sbic    PBPinO,PButtO   ;Sicherstellen eines definierten Ausgangs-
        rjmp	DEBPBO          ;zustandes
DEBPBO1: sbis   PBPinO,PButtO   ;Warten auf erste Tasterbetaetigung
        rjmp	DEBPBO1
	rcall	W10ms		;Totzeit
        sbis    PBPinO,PButtO   ;Bestätigung des Schaltzustandes
        rjmp	DEBPBO1

DEBPBO2: sbic   PBPinO,PButtO   ;Warten auf Loslassen des Tasters
        rjmp	DEBPBO2
	rcall	W10ms		;Totzeit
        sbic    PBPinO,PButtO   ;Bestätigung des Loslassens
        rjmp	DEBPBO2
	ret

