;-------------------------------------------------------------------------------
;	Unterprogramm I2C-Bus
;	Daten in r17 (Tmp2)
;		
;-------------------------------------------------------------------------------

;-------------------------------------------------------------------------------
;	Daten senden
;-------------------------------------------------------------------------------
SNDALL:	push	r16	
	push	r17	
	rcall	STAI2C		;Startbit senden
	ldi	r17,$D0		;Adresse des RTC DS1307 (Maxim 1101000) senden
	rcall	SNDI2C		;Bit 2^0 = 0 Senden
	ldi	r17,$00		;Adresszeiger = 0 senden
	rcall	SNDI2C
        clr     r17             ;3 Datenbyte (Sekunden, Stunden und Minuten)
        rcall   SNDI2C
        mov	r17,MinDCF      
	rcall	SNDI2C
	mov	r17,HrsDCF
	rcall	SNDI2C
	rcall	STOI2C		;Stoppbit senden
	pop	r17
	pop	r16
	ret

;-------------------------------------------------------------------------------
;	Daten empfangen
;-------------------------------------------------------------------------------
RECALL:	push	r16	
	push	r17	
	rcall	STAI2C		;Startbit senden
	ldi	r17,$D0		;Adresse des RTC DS1307 (Maxim 1101000) senden
	rcall	SNDI2C		;Bit 2^0 = 0 Senden
	ldi	r17,$00		;Adresszeiger = 0 senden
	rcall	SNDI2C
	rcall	STOI2C		;Stoppbit senden
	rcall	STAI2C		;Startbit senden
	ldi	r17,$D1		;Adresse des RTC DS1307 (Maxim 1101000) senden
	rcall	SNDI2C		;Bit 2^0 = 1 Lesen
	rcall	RACKI2C         ;Sekunden (hier nicht benoetigt)
        rcall   RACKI2C         
	mov	Minutes,r17
	rcall	RACKI2C
	mov	Hours,r17
	rcall	RNAKI2C         ;Achtung! mit NAK abschliessen
	rcall	STOI2C		;Stoppbit senden
	pop	r17
	pop	r16
	ret

;-------------------------------------------------------------------------------
;	I2C-Bus Funktionen (Daten in r17, Status in r16)
;-------------------------------------------------------------------------------
;I2C (TWI) initialisieren
INII2C: ldi     r16,98          ;Teile durch dezimal 98 für SCL=10kHz
        out     TWBR,Tmp1       ;44=((8000000/10000)-16)/(2*4^(TWPS))
        clr     r16             ;Vorteiler TWPS = 1 (siehe TWSR)
        out     TWSR,r16        ;das Einschalten der Baugruppe (TWEN in TWCR)
        ret                     ;erfolgt jeweils beim Ansteuern

; Startbit
STAI2C:	ldi	r16,$A4		;TWCR=10100100b TWINT,TWSTA u. TWEN setzen
	out	TWCR,r16
STA1:	in	r16,TWCR	;warten bis TWINT wieder 1
	sbrs	r16,TWINT	;Operation beendet
	rjmp	STA1	
	in	r16,TWSR	;Status-Code in r16
	andi	r16,$F8
	ret

;Daten senden
SNDI2C:	out	TWDR,r17	;r17 (Daten) ins Datenregister
	ldi	r16,$84		;TWCR=10000100b TWINT u. TWEN setzen
	out	TWCR,r16	
SEND1:	in	r16,TWCR	;warten bis TWINT wieder 1
	sbrs	r16,TWINT	;Operation beendet
	rjmp	SEND1	
	in	r16,TWSR	;Status-Code in r16
	andi	r16,$F8
	ret

;Daten empfangen mit ACK
RACKI2C: ldi	r16,$C4		;TWCR=11000100b TWINT, TWEA u. TWEN setzen
	out	TWCR,r16	
ACK1:	in	r16,TWCR	;warten bis TWINT wieder 1
	sbrs	r16,TWINT	;(Start-Operation beendet)
	rjmp	ACK1	
	in	r17,TWDR	;Daten in r17
	in	r16,TWSR	;Status-Code in r16
	andi	r16,$F8
	ret

;Daten empfangen ohne ACK
RNAKI2C: ldi	r16,$84		;TWCR=10000100b TWINT u. TWEN setzen
	out	TWCR,r16	
NACK1:	in	r16,TWCR	;warten bis TWINT wieder 1
	sbrs	r16,TWINT	;(Start-Operation beendet)
	rjmp	NACK1	
	in	r17,TWDR	;Daten in r17
	in	r16,TWSR	;Status-Code in r16
	andi	r16,$F8
	ret

;Stoppbit
STOI2C:	ldi	r16,$94		;TWCR=10010100b TWINT u. TWEN setzen
	out	TWCR,r16	
	ret





